evolution_schema::column

Struct FixedColumn

source
pub struct FixedColumn { /* private fields */ }
Representation of a column in a fixed-length file (.flf), containing the only allowed fields.

Note

This struct is meant to be created when deserializing a .json schema file representing a crate::schema::FixedSchema, and as such, capitalization of the field values is extremely important. For example, the dtype field has to be exactly one of the DataType enum variants, spelled exactly the same. Otherwise, serde can’t deserialize the values.

Implementations

source

impl FixedColumn

source

pub fn new( name: String, offset: usize, length: usize, dtype: DataType, alignment: Alignment, pad_symbol: Symbol, is_nullable: bool, ) -> Self

Create a new FixedColumn from the provided field values.

source

pub fn name(&self) -> &String

Get the name of the column.

source

pub fn offset(&self) -> usize

Get the starting offset of the column (in runes).

source

pub fn length(&self) -> usize

Get the total length of the column (in runes).

source

pub fn dtype(&self) -> DataType

Get the datatype of the column (as a DataType variant).

source

pub fn alignment(&self) -> Alignment

Get the alignment mode of the column (as an Alignment variant).

source

pub fn pad_symbol(&self) -> Symbol

Get the symbol used to pad the column to its expected length (as a Symbol variant).

source

pub fn is_nullable(&self) -> bool

Get whether or not the column is allowed to be nullable.

Note

If a column is defined as not nullable and parsing of a fixed-length file column fails to find a valid value, then a NULL value will not be appended to the column builder. Instead, the program will terminate due to this occurring.

source

pub fn as_arrow_dtype(&self) -> ArrowDataType

Get the datatype of the column as a ArrowDataType variant.

source

pub fn as_delta_dtype(&self) -> DeltaDataType

Get the datatype of the column as a DeltaDataType variant.

Note

Currently this method will map DataType::Float16 to the DataType::Float32 variant. This is because the deltalake crate does not yet define a Float16 variant in its DeltaDataType.

source

pub fn as_column_builder(&self) -> ColumnBuilderRef

Create a new ColumnBuilderRef based on the datatype of the column.

Performance

This method will clone the String which contains the name of the column. You should only use this during setup of the program, and not during any performance critical parts of the program.