pub struct FixedSchema { /* private fields */ }Expand description
Representation of the schema for a fixed-length file (.flf), containing the only allowed fields.
Implementations
Sourceimpl FixedSchema
impl FixedSchema
Sourcepub fn new(name: String, version: usize, columns: Vec<FixedColumn>) -> Self
pub fn new(name: String, version: usize, columns: Vec<FixedColumn>) -> Self
Create a new FixedSchema from the provided field values.
Sourcepub fn from_path(path: PathBuf) -> Result<Self>
pub fn from_path(path: PathBuf) -> Result<Self>
Create a new FixedSchema by reading a .json file at the provided path.
Errors
This function will return an error under a number of different circumstances. These error conditions are listed below.
NotFound: The specified file does not exist and neithercreateorcreate_newis set.NotFound: One of the directory components of the file path does not exist.PermissionDenied: The user lacks permission to get the specified access rights for the file.PermissionDenied: The user lacks permission to open one of the directory components of the specified path.AlreadyExists:create_newwas specified and the file already exists.InvalidInput: Invalid combinations of open options (truncate without write access, no access mode set, etc.).
Examples
use evolution_schema::schema::FixedSchema;
use std::path::PathBuf;
let path: PathBuf = PathBuf::from(r"/path/to/my/schema.json");
let schema: FixedSchema = FixedSchema::from_path(path).unwrap();
println!("This is my cool schema: {:?}", schema);Sourcepub fn columns(&self) -> &Vec<FixedColumn>
pub fn columns(&self) -> &Vec<FixedColumn>
Get the columns of the schema.
Sourcepub fn num_columns(&self) -> usize
pub fn num_columns(&self) -> usize
Get the number of columns in the schema.
Sourcepub fn row_length(&self) -> usize
pub fn row_length(&self) -> usize
Get the total length of a fixed-length row.
Sourcepub fn column_names(&self) -> Vec<&String>
pub fn column_names(&self) -> Vec<&String>
Get the names of the columns.
Sourcepub fn column_offsets(&self) -> Vec<usize>
pub fn column_offsets(&self) -> Vec<usize>
Get the offset indices for each column (in number of runes).
Sourcepub fn column_lengths(&self) -> Vec<usize>
pub fn column_lengths(&self) -> Vec<usize>
Get the lengths of each column (in number of runes).
Sourcepub fn nullable_columns(&self) -> Vec<&FixedColumn>
pub fn nullable_columns(&self) -> Vec<&FixedColumn>
Get the columns that are nullable.
Sourcepub fn not_nullable_columns(&self) -> Vec<&FixedColumn>
pub fn not_nullable_columns(&self) -> Vec<&FixedColumn>
Get the columns that are not nullable.
Sourcepub fn iter(&self) -> FixedSchemaIterator<'_> ⓘ
pub fn iter(&self) -> FixedSchemaIterator<'_> ⓘ
Borrow the vector of FixedColumns and create a new iterator with it.
Sourcepub fn into_arrow_schema(self) -> ArrowSchema
pub fn into_arrow_schema(self) -> ArrowSchema
Consume the FixedSchema and produce an ArrowSchema from it.
Sourcepub fn into_builder<T>(self) -> Twhere
T: Builder,
pub fn into_builder<T>(self) -> Twhere
T: Builder,
Consume the FixedSchema and produce an instance of a Builder from it.