evolution_schema::schema

Struct FixedSchema

source
pub struct FixedSchema { /* private fields */ }
Representation of the schema for a fixed-length file (.flf), containing the only allowed fields.

Implementations

source

impl FixedSchema

source

pub fn new(name: String, version: usize, columns: Vec<FixedColumn>) -> Self

Create a new FixedSchema from the provided field values.

source

pub fn from_path(path: PathBuf) -> Result<Self>

Create a new FixedSchema by reading a .json file at the provided path.

Errors

This function will return an error under a number of different circumstances. These error conditions are listed below.

  • NotFound: The specified file does not exist and neither create or create_new is set.
  • NotFound: One of the directory components of the file path does not exist.
  • PermissionDenied: The user lacks permission to get the specified access rights for the file.
  • PermissionDenied: The user lacks permission to open one of the directory components of the specified path.
  • AlreadyExists: create_new was specified and the file already exists.
  • InvalidInput: Invalid combinations of open options (truncate without write access, no access mode set, etc.).
Examples
use evolution_schema::schema::FixedSchema;
use std::path::PathBuf;

let path: PathBuf = PathBuf::from(r"/path/to/my/schema.json");
let schema: FixedSchema = FixedSchema::from_path(path).unwrap();

println!("This is my cool schema: {:?}", schema);
source

pub fn name(&self) -> &str

Get the name of the schema.

source

pub fn version(&self) -> usize

Get the version of the schema.

source

pub fn columns(&self) -> &Vec<FixedColumn>

Get the columns of the schema.

source

pub fn num_columns(&self) -> usize

Get the number of columns in the schema.

source

pub fn row_length(&self) -> usize

Get the total length of a fixed-length row.

source

pub fn column_names(&self) -> Vec<&String>

Get the names of the columns.

source

pub fn column_offsets(&self) -> Vec<usize>

Get the offset indices for each column (in number of runes).

source

pub fn column_lengths(&self) -> Vec<usize>

Get the lengths of each column (in number of runes).

source

pub fn nullable_columns(&self) -> Vec<&FixedColumn>

Get the columns that are nullable.

source

pub fn not_nullable_columns(&self) -> Vec<&FixedColumn>

Get the columns that are not nullable.

source

pub fn dtypes(&self) -> Vec<DataType>

Get the datatype of each column.

source

pub fn iter(&self) -> FixedSchemaIterator<'_>

Borrow the vector of FixedColumns and create a new iterator with it.

source

pub fn into_arrow_schema(self) -> ArrowSchema

Consume the FixedSchema and produce an ArrowSchema from it.

source

pub fn into_builder<T>(self) -> T
where T: Builder,

Consume the FixedSchema and produce an instance of a Builder from it.